@@ -68,18 +68,19 @@ def entities_to_json(entities, sort_keys=False, indent=None, cls=None):
     return json.dumps(entities, default=_entity_json_encoder, sort_keys=sort_keys,
                       indent=indent, cls=cls)
 
-def parse_entity(entity_as_string):
+def parse_entity(entity_as_string, do_transit_decoding=True):
     dummy_stream_data = "[" + entity_as_string + "]"
     dummy_stream = io.BytesIO(dummy_stream_data.encode("utf-8"))
-    entities = list(parse_json_stream(dummy_stream))
+    entities = list(parse_json_stream(dummy_stream, do_transit_decoding=do_transit_decoding))
     assert len(entities) == 1
     return entities[0]
 
 
-def parse_json_stream(stream):
+def parse_json_stream(stream, do_transit_decoding=True):
     """Parses stream of JSON entities. Stream can contain either a single
     JSON object or a list of JSON objects.
-    :param file-like stream object
+    :param stream: file-like stream object
+    :param do_transit_decoding: bool determining if transit decoding should be performed
     :return: a generator of entity objects
     """
     context = []
@@ -92,7 +93,7 @@ def parse_json_stream(stream):
         elif event == 'string':
             ctxobj = context[-1]
             if type(ctxobj) is list:
-                if len(value) > 1 and value[0] == "~":
+                if do_transit_decoding is True and len(value) > 1 and value[0] == "~":
                     value1 = value[1]
                     #if value1 == "r":
                     #    ctxobj.append(URI(value[2:]))
@@ -114,7 +115,7 @@ def parse_json_stream(stream):
                     ctxobj.append(value)
             elif type(ctxobj) is dict:
                 prop_name = name_context.pop()
-                if len(value) > 1 and value[0] == "~":
+                if do_transit_decoding is True and len(value) > 1 and value[0] == "~":
                     value1 = value[1]
                     #if value1 == "r":
                     #    ctxobj[prop_name] = URI(value[2:])
